#
# spec file for package libmanette
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binary_version 0.2
%define package_version 0_2-0

Name:           libmanette
Version:        0.2.9
Release:        1.2
Summary:        A simple GObject game controller library
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://gnome.pages.gitlab.gnome.org/libmanette/
Source:         %{name}-%{version}.tar.zst
Source99:       baselibs.conf
BuildRequires:  gcc
BuildRequires:  gobject-introspection-devel >= 0.6.7
BuildRequires:  meson >= 0.53.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gudev-1.0) >= 1.0
BuildRequires:  pkgconfig(libevdev) >= 1.4.5
BuildRequires:  pkgconfig(vapigen)

%description
libmanette allows easy access to game controllers.

%package -n libmanette-%{package_version}
Summary:        A simple GObject game controller library
Group:          System/Libraries

%description -n libmanette-%{package_version}
libmanette allows easy access to game controllers.

%package -n typelib-1_0-Manette-%{package_version}
Summary:        GObject introspection bindings for liblibmanette
Group:          System/Libraries

%description -n typelib-1_0-Manette-%{package_version}
libmanette allows easy access to game controllers.
This subpackage contains the gobject bindings for the liblibmanette
shared library.

%package devel
Summary:        Development files for the libmanette library
Group:          Development/Languages/C and C++
Requires:       libmanette-%{package_version} = %{version}

%description devel
libmanette allows easy access to game controllers.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%post -n libmanette-%{package_version} -p /sbin/ldconfig
%postun -n libmanette-%{package_version} -p /sbin/ldconfig

%files -n libmanette-%{package_version}
%license COPYING
%{_libdir}/libmanette-%{binary_version}.so.*

%files -n typelib-1_0-Manette-%{package_version}
%{_libdir}/girepository-1.0/Manette-%{binary_version}.typelib

%files devel
%{_bindir}/manette-test
%{_datadir}/gir-1.0/Manette-%{binary_version}.gir
%dir %{_datadir}/vala/
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/manette-%{binary_version}.deps
%{_datadir}/vala/vapi/manette-%{binary_version}.vapi
%{_includedir}/libmanette/
%{_libdir}/libmanette-%{binary_version}.so
%{_libdir}/pkgconfig/manette-%{binary_version}.pc

%changelog
* Fri Sep 13 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.9:
  + Update and clean up the game controller mapping database
  + ManetteDevice:
  - add manette_device_get_mapping() and
    manette_device_get_guid()
  - Handle keycodes before BTN_MISC as well
  + ManetteMapping:
  - Allow to map paddle1-4, misc1-6 and touchpad buttons
  - Improve error handling
  + ManetteMappingManager: Check if user mapping file exists
  + Tests: Test default mappings
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.2.7:
  + Allow building as a static library.
  + ManetteMappingManager: Strip leading and trailing spaces from
    mappings.
  + ManetteMonitor:
  - Always use file backend in Flatpak.
  - Skip non-evdev devices.
  - Fix object construction.
  + Various cleanups.
* Sun Mar 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add baselibs.conf: build libmanette-0_2-0. New dependency to
  webkit2gtk3.
* Sat Nov 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.6:
  + Project:
  - Move the project to gitlab.gnome.org/GNOME/libmanette.
  - Update the URLs accordingly.
  - Give the project a minimal website:
    https://gnome.pages.gitlab.gnome.org/libmanette/
  - Update the project's description.
  + Documentation:
  - Add a documentation.
  - Fix many documentation annotations.
  - Document more symbols.
  + Meson:
  - Require Meson 0.53.0.
  - Add the demos option.
  - Add the build-tests and install-tests option.
  - Various code style cleanups and updates.
  - Add a build summary.
  + ManetteDevice:
  - Add a missing precondition check to ensure milliseconds is in
    the right range in manette_device_rumble().
  - Throw the full file error code rather than G_FILE_ERROR_FAILED
    in manette_device_new().
  - Throw G_FILE_ERROR_FAILED rather than G_FILE_ERROR_NXIO in
    manette_device_new() if the device isn't a gamepad.
  + ManetteMapping:
  - Check mapping strings have at least a GUID field and a name
    field.
  - Use the debug log level for non-programming mapping parsing
    errors.
  - Make some parsing error messages more explicit.
  + ManetteMappingManager: Use a race-free way to check the mapping
    file deletion.
  + Code cleanup:
  - Make license headers have the LGPL footer, not the GPL one.
  - Use #pragma once instead of manual header guards.
  - Use g_auto(), g_autoptr() and g_autofree where possible.
  - Use g_clear_pointer() and g_clear_object() where possible.
  - Use assertions instead of g_return*_if_fail in static
    functions.
  - Add HACKING.md to document the code, documentation, and
    commit message styles.
  - Give better names to callback functions.
  - Give the namespace_object_ prefix to the finalize functions
    to match the code style.
  - Clean up and simplify the code in many places.
  - Drop platform:Linux from the internal gamepad database.
- Changes from version 0.2.5:
  + Fix the build with musl by using input_event_sec and
    input_event_usec.
- Run tests during build, add a check section and macro.
- Update URL to new home.
* Sun Apr  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.4:
  + Build system changes: Add the 'introspection' and 'vapi'
    options, allowing to build without producing GObject
    Introspection or Vala bindings.
  + Support hot-plugging in the fallback backend.
  + Update the game controller mapping database.
  + Various code cleanups.
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.3:
  + Build system changes: Add 'gudev' option, allowing to
    explicitly build without gudev.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.2:
  + Device:
  - Handle absolute axes with min > 0.
  - Handle the axes' flat to support axes to d-pad mapping.
  + Mapping:
  - Support negative analog axis to button mappings.
  - Support full-range axis to button mappings.
* Sun Sep 23 2018 antoine.belvire@opensuse.org
- Update to version 0.2.1:
  + Defer the emission of input device events by putting them into
    idle event sources.
  + Update the game controller database.
* Tue Mar  6 2018 bjorn.lie@gmail.com
- Update to version 0.2.0:
  + Device: Add rumble support.
  + Make the devices rumble in manette-test if they support it.
  + Mapping:
  - Initialize the bindings to 0 before using them, avoiding
    improper values in non used fields.
  - Ensures the binding value inversion is disabled by default,
    avoiding an unexpected state.
  - Clear errno before using it to avoid string to uint16
    convertions to fail on valid inputs.
  - Silently skip the 'platform' mapping key as it is neither
    useful nor erroneous.
  + Monitor:
  - Fix the 'device-disconnected' signal marshaller.
  - Fix the devices hash table hash and comparison functions.
  + Build system change:
  - Make manette-test properly depend on libmanette.
  - Change the package name from libmanette to manette.
  - Change the soname from liblibmanette.so to libmanette.so.
  - Fix the soname version.
  + Fix the license header of manette-version.h.in, which was
    accidentaly not matching the one of the library.
- Following upstream changes and fixes, rename liblibmanette-0_2
  subpackage to libmanette-0_2-0, change where applicable, set
  package_version define to 0_2-0.
- Tweak spec, use autosetup macro.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Nov 20 2017 adrien.plazas@suse.com
- Initial package, libmanette, version 0.1.2.
